==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/sn_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//section titles
$lang['section_menu'] = 						"menu";
$lang['section_action'] = 						"do";
$lang['section_member'] = 						"member";
$lang['section_comments'] = 					"comments";
$lang['section_add_comment'] = 					"add comment";
$lang['section_not_in_sn'] = 					"your social network";


//HDR
$lang['hdr_comment_preview'] = 					"comment preview";


//MENU
$lang['menu_social_network'] = 					"social network";
$lang['menu_invite_friends'] = 					"invite friends";
$lang['menu_statistics'] = 						"statistics";
$lang['menu_profile'] = 						"profile";
$lang['menu_blog'] =							"blog";
$lang['menu_friends'] = 						"friends";
$lang['menu_library'] = 						"library";
$lang['menu_publishing'] = 						"publishing";
$lang['menu_recommended'] = 					"recommended";
$lang['menu_send_message'] = 					"send a message";
$lang['menu_blocked_users'] = 					"blocked users";
$lang['menu_channels'] = 						"channels";


//SUBMIT BUTTONS
$lang['sub_add'] = 								"add";
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_preview'] = 							"preview";
$lang['sub_save'] = 							"save";


//A HREF TAGS (links)
$lang['href_block'] = 							"block this user";
$lang['href_latest_blog'] = 					"latest blog";
$lang['href_blog_list'] = 						"list";


//TITLE TAGS (rollovers)
$lang['ttl_send_message'] = 					"send message";


//ERRORS
$lang['err_no_library'] = 						"Sorry, this person has no library items.";
$lang['err_no_blogs'] = 						"Sorry, this person has no blog items.";
$lang['err_no_friends'] = 						"Sorry, this person does not have anyone in their social network.";
$lang['err_no_groups'] = 						"Sorry, this person is not a member of any groups.";
$lang['err_no_file'] = 							"Sorry, file available.";
$lang['err_no_poll_participation'] =			"Sorry, this person has not placed any votes.";
$lang['err_no_shouts'] = 						"Sorry, this person has no shouts.";
$lang['err_no_statistics'] = 					"Sorry, no statistics available.";
$lang['err_no_forum'] = 						"Sorry, this person has no discussion items.";
$lang['err_not_in_social_network'] = 			"Sorry, this person is not in your social network.";
$lang['err_no_comments'] = 						"Sorry, no comments available.";


//BODY TEXT
$lang['txt_genre'] = 							"genre";
$lang['txt_total_views'] = 						"total views";
$lang['txt_user_acquaintances'] = 				"acquaintances";
$lang['txt_blog'] = 							"blog";//breadcrumb
$lang['txt_friends'] = 							"friends";//breadcrumb
$lang['txt_library'] = 							"library";//breadcrumb
$lang['txt_network'] =							"social network";//breadcrumb
$lang['txt_publishing'] = 						"publishing";//breadcrumb
$lang['txt_profile'] = 							"profile";//breadcrumb
$lang['txt_recommended'] = 						"recommended";//breadcrumb
$lang['txt_statistics'] = 						"statistics";//breadcrumb
$lang['txt_votes'] = 							"votes";
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['txt_comment_help'] = 					"Remember to observe the rules of the community.";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_from'] =								"From";
$lang['txt_author'] = 							"author";
$lang['txt_hometown'] = 						"home town";
$lang['txt_last_edit'] = 						"last edit by";
$lang['txt_joined'] = 							"joined";
$lang['txt_check_spelling'] =					"Check Spelling";
$lang['txt_profile_create_datetime'] = 			"joined";
$lang['txt_profile_hometown'] = 				"home town";
$lang['txt_profile_nic'] = 						"nickname";
$lang['txt_profile_session_status'] = 			"status";
$lang['txt_group_language'] = 					"language";

?>

==> aroundme_0_6_2.zip: aroundme_0_6_2/aroundme/language/1/barnraiser_01/sn_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

//section titles
$lang['hdr_menu'] = 						"menu";
$lang['hdr_action'] = 						"do";
$lang['hdr_member'] = 						"member";
$lang['hdr_not_in_sn'] = 					"your social network";


//A HREF TAGS (links)
$lang['href_block'] = 							"block this user";


//TITLE TAGS (rollovers)
$lang['ttl_send_message'] = 					"send message";


//ERRORS
$lang['err_no_library'] = 						"Sorry, this person has no library items.";
$lang['err_no_blogs'] = 						"Sorry, this person has no blog items.";
$lang['err_no_relations'] = 					"Sorry, this person does not have anyone in their social network.";
$lang['err_no_file'] = 							"Sorry, file available.";
$lang['err_no_poll_participation'] =			"Sorry, this person has not placed any votes.";
$lang['err_no_shouts'] = 						"Sorry, this person has no shouts.";
$lang['err_no_statistics'] = 					"Sorry, no statistics available.";
$lang['err_no_forum'] = 						"Sorry, this person has no discussion items.";
$lang['err_not_in_social_network'] = 			"Sorry, this person is not in your social network.";
$lang['err_no_comments'] = 						"Sorry, no comments available.";


//BODY TEXT
$lang['txt_total_views'] = 						"total views";
$lang['txt_user_acquaintances'] = 				"acquaintances";
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['txt_comment_help'] = 					"Remember to observe the rules of the community.";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_last_edit'] = 						"last edit by";
$lang['txt_tag'] = 								"tag";

$lang['txt_help_icon_conn'] = 					"connected to";
$lang['txt_help_icon_net'] = 					"They can see my network";
$lang['txt_help_icon_ts'] = 					"true self revealed";
$lang['txt_help_icon_conn2'] = 					"connected to me";
$lang['txt_help_icon_net2'] = 					"I can see their network";
$lang['txt_help_icon_ts2'] = 					"true self revealed to me";

?>
